#!/bin/sh 


# base path 
path='./data' 

# set case upper|lower (default upper if no case) 
case='lower'

# check for valid path 
if [ "$path" = "" ]; then 
      echo "Usage: $0 [BASE PATH TO MODIFY] [CASE (upper|lower)]" 
      echo "Example: $0 /modify/path upper" 
      echo 
      exit 
fi 

# check for valid path (must be valid dir) 
if [ ! -d "$path" ]; then 
      echo "Error: failed to find directory '$path'" 
      echo 
      exit 
fi 

# format case to lower 
case=`echo $case | tr ['A-Z'] ['a-z']` 

# format case pattern (uppper|lower) 
[ "$case" = "upper" ] && case="['a-z'] ['A-Z']" || case="['A-Z'] ['a-z']" 

# format safe dir 
safepath=`echo $path | sed -e 's/////g'` 

# count num of dir modified 
dirs_mod=0 

# modify directories 
for each in `find $path -type d` 
do       
      # new dir only (not including base path) 
      dir=`echo $each | sed s/^$safepath//` 
       
      # set new dir name (correct case) 
      newdir=`echo $dir | tr $case`

      tmp_name='.tmp_name_for_renaming_823764582746'

      # check if new dir name diff 
      if [ "$dir" != "$newdir" ]; then 

            mv -f $each $newdir$tmp_name
            mv -f $newdir$tmp_name $newdir

            dirs_mod=`expr $dirs_mod + 1` 
            echo "Modified $each => $newdir" 
      fi       
done 

# count num of files modified 
files_mod=0 

# modify files 
for each in `find $path -type f` 
do 
      # new file only (not including base path) 
      filename=`echo $each | sed s/^$safepath//` 

      # set new filename (correct case) 
      newfilename=`echo $filename | tr $case` 
      tmp_name='.tmp_name_for_renaming_823764582746' 


      # check if new filename diff 
      if [ "$filename" != "$newfilename" ]; then 
            mv -f $each $newfilename$tmp_name 
            mv -f $newfilename$tmp_name $newfilename 
            files_mod=`expr $files_mod + 1` 
            echo "Modified $each => $newfilename" 
      fi 
done 

echo 
echo DONE 
echo "$dirs_mod directories modified" 
echo "$files_mod files modified" 
echo